@@ -46,7 +46,7 @@ module Puppet
 
   # Contains an issue code and can be annotated with an environment and a node
   class ParseErrorWithIssue < Puppet::ParseError
-    attr_reader :issue_code, :basic_message
+    attr_reader :issue_code, :basic_message, :arguments
     attr_accessor :environment, :node
 
     # @param message [String] The error message
@@ -55,11 +55,13 @@ module Puppet
     # @param pos [Integer] The position on the line
     # @param original [Exception] Original exception
     # @param issue_code [Symbol] The issue code
+    # @param arguments [Hash{Symbol=>Object}] Issue arguments
     #
-    def initialize(message, file=nil, line=nil, pos=nil, original=nil, issue_code= nil)
+    def initialize(message, file=nil, line=nil, pos=nil, original=nil, issue_code= nil, arguments = nil)
       super(message, file, line, pos, original)
       @issue_code = issue_code
       @basic_message = message
+      @arguments = arguments
     end
 
     def to_s
@@ -68,6 +70,24 @@ module Puppet
       msg = _("%{message} on node %{node}") % { message: msg, node: node } if node
       msg
     end
+
+    def self.from_issue_and_stack(issue, args = {})
+      stacktrace = Puppet::Pops::PuppetStack.stacktrace()
+      if stacktrace.size > 0
+        filename, line = stacktrace[0]
+      else
+        filename = nil
+        line = nil
+      end
+      self.new(
+            issue.format(args),
+            filename,
+            line,
+            nil,
+            nil,
+            issue.issue_code,
+            args)
+    end
   end
 
   # An error that already contains location information in the message text
