@@ -20,24 +20,24 @@
 #
 # @example Using the `map` function with an array and a one-parameter lambda
 #
-# ~~~ puppet
+# ```puppet
 # # For the array $data, return an array containing each value multiplied by 10
 # $data = [1,2,3]
 # $transformed_data = $data.map |$items| { $items * 10 }
 # # $transformed_data contains [10,20,30]
-# ~~~
+# ```
 #
 # When the first argument is a hash, Puppet passes each key and value pair to the lambda
 # as an array in the form `[key, value]`.
 #
 # @example Using the `map` function with a hash and a one-parameter lambda
 #
-# ~~~ puppet
+# ```puppet
 # # For the hash $data, return an array containing the keys
 # $data = {'a'=>1,'b'=>2,'c'=>3}
 # $transformed_data = $data.map |$items| { $items[0] }
 # # $transformed_data contains ['a','b','c']
-# ~~~
+# ```
 #
 # When the first argument is an array and the lambda has two parameters, Puppet passes the
 # array's indexes (enumerated from 0) in the first parameter and its values in the second
@@ -45,24 +45,24 @@
 #
 # @example Using the `map` function with an array and a two-parameter lambda
 #
-# ~~~ puppet
+# ```puppet
 # # For the array $data, return an array containing the indexes
 # $data = [1,2,3]
 # $transformed_data = $data.map |$index,$value| { $index }
 # # $transformed_data contains [0,1,2]
-# ~~~
+# ```
 #
 # When the first argument is a hash, Puppet passes its keys to the first parameter and its
 # values to the second parameter.
 #
 # @example Using the `map` function with a hash and a two-parameter lambda
 #
-# ~~~ puppet
+# ```puppet
 # # For the hash $data, return an array containing each value
 # $data = {'a'=>1,'b'=>2,'c'=>3}
 # $transformed_data = $data.map |$key,$value| { $value }
 # # $transformed_data contains [1,2,3]
-# ~~~
+# ```
 #
 # @since 4.0.0
 #
@@ -107,7 +107,6 @@ Puppet::Functions.create_function(:map) do
 
   def map_Enumerable_1(enumerable)
     result = []
-    index = 0
     enum = Puppet::Pops::Types::Iterable.asserted_iterable(self, enumerable)
     begin
       loop { result << yield(enum.next) }
@@ -117,16 +116,21 @@ Puppet::Functions.create_function(:map) do
   end
 
   def map_Enumerable_2(enumerable)
-    result = []
-    index = 0
     enum = Puppet::Pops::Types::Iterable.asserted_iterable(self, enumerable)
-    begin
-      loop do
-        result << yield(index, enum.next)
-        index = index +1
+    if enum.hash_style?
+      enum.map { |entry| yield(*entry) }
+    else
+      result = []
+      begin
+        index = 0
+        loop do
+          result << yield(index, enum.next)
+          index = index + 1
+        end
+      rescue StopIteration
       end
-    rescue StopIteration
+
+      result
     end
-    result
   end
 end
