@@ -10,6 +10,8 @@ require 'puppet/pops'
 # Maintain a graph of scopes, along with a bunch of data
 # about the individual catalog we're compiling.
 class Puppet::Parser::Compiler
+  include Puppet::Parser::AbstractCompiler
+
   extend Forwardable
 
   include Puppet::Util
@@ -39,7 +41,7 @@ class Puppet::Parser::Compiler
     message = _("%{message} on node %{node}") % { message: detail, node: node.name }
     Puppet.log_exception(detail, message)
     raise Puppet::Error, message, detail.backtrace
- end
+  end
 
   attr_reader :node, :facts, :collections, :catalog, :resources, :relationships, :topscope
   attr_reader :qualified_variables
@@ -458,10 +460,10 @@ class Puppet::Parser::Compiler
       component_ref = args['component']
       kind = args['kind']
 
-      # That component_ref is either a QNAME or a Class['literal'|QREF] is asserted during validation so no
+      # That component_ref is either a QREF or a Class['literal'|QREF] is asserted during validation so no
       # need to check that here
-      if component_ref.is_a?(Puppet::Pops::Model::QualifiedName)
-        component_name = component_ref.value
+      if component_ref.is_a?(Puppet::Pops::Model::QualifiedReference)
+        component_name = component_ref.cased_value
         component_type = 'type'
         component = krt.find_definition(component_name)
       else
@@ -662,7 +664,7 @@ class Puppet::Parser::Compiler
         data[target] = source_data.merge(metaparams_as_data(target, names))
       end
 
-      target.tag(*(source.tags))
+      target.merge_tags_from(source)
     end
   end
 
@@ -719,6 +721,7 @@ class Puppet::Parser::Compiler
     Puppet.override( @context_overrides , _("For initializing compiler")) do
       # THE MAGIC STARTS HERE ! This triggers parsing, loading etc.
       @catalog.version = environment.known_resource_types.version
+      @loaders.pre_load
     end
 
     @catalog.add_resource(Puppet::Parser::Resource.new("stage", :main, :scope => @topscope))
@@ -737,62 +740,23 @@ class Puppet::Parser::Compiler
   end
 
   def sanitize_node(node)
-    # Resurrect "trusted information" that comes from node/fact terminus.
-    # The current way this is done in puppet db (currently the only one)
-    # is to store the node parameter 'trusted' as a hash of the trusted information.
-    #
-    # Thus here there are two main cases:
-    # 1. This terminus was used in a real agent call (only meaningful if someone curls the request as it would
-    #  fail since the result is a hash of two catalogs).
-    # 2  It is a command line call with a given node that use a terminus that:
-    # 2.1 does not include a 'trusted' fact - use local from node trusted information
-    # 2.2 has a 'trusted' fact - this in turn could be
-    # 2.2.1 puppet db having stored trusted node data as a fact (not a great design)
-    # 2.2.2 some other terminus having stored a fact called "trusted" (most likely that would have failed earlier, but could
-    #       be spoofed).
-    #
-    # For the reasons above, the resurrection of trusted node data with authenticated => true is only performed
-    # if user is running as root, else it is resurrected as unauthenticated.
-    #
-    trusted_param = node.parameters['trusted']
-    if trusted_param
-      # Blows up if it is a parameter as it will be set as $trusted by the compiler as if it was a variable
-      node.parameters.delete('trusted')
-      unless trusted_param.is_a?(Hash) && %w{authenticated certname extensions}.all? {|key| trusted_param.has_key?(key) }
-        # trusted is some kind of garbage, do not resurrect
-        trusted_param = nil
-      end
-    else
-      # trusted may be Boolean false if set as a fact by someone
-      trusted_param = nil
-    end
-
-    # The options for node.trusted_data in priority order are:
-    # 1) node came with trusted_data so use that
-    # 2) else if there is :trusted_information in the puppet context
-    # 3) else if the node provided a 'trusted' parameter (parsed out above)
-    # 4) last, fallback to local node trusted information
-    #
-    # Note that trusted_data should be a hash, but (2) and (4) are not
-    # hashes, so we to_h at the end
-    if !node.trusted_data
-      trusted = Puppet.lookup(:trusted_information) do
-        trusted_param || Puppet::Context::TrustedInformation.local(node)
-      end
-
-      # Ruby 1.9.3 can't apply to_h to a hash, so check first
-      node.trusted_data = trusted.is_a?(Hash) ? trusted : trusted.to_h
-    end
-
+    node.sanitize
     node
   end
 
   # Set the node's parameters into the top-scope as variables.
   def set_node_parameters
     node.parameters.each do |param, value|
+      # We don't want to set @topscope['environment'] from the parameters,
+      # instead we want to get that from the node's environment itself in
+      # case a custom node terminus has done any mucking about with
+      # node.parameters.
+      next if param.to_s == 'environment'
       # Ensure node does not leak Symbol instances in general
       @topscope[param.to_s] = value.is_a?(Symbol) ? value.to_s : value
     end
+    @topscope['environment'] = node.environment.name.to_s
+
     # These might be nil.
     catalog.client_version = node.parameters["clientversion"]
     catalog.server_version = node.parameters["serverversion"]
