@@ -16,7 +16,7 @@ module Puppet::Util::Windows::ADSI
       begin
         WIN32OLE.connect(uri)
       rescue WIN32OLERuntimeError => e
-        raise Puppet::Error.new( "ADSI connection error: #{e}", e )
+        raise Puppet::Error.new( _("ADSI connection error: %{e}") % { e: e }, e )
       end
     end
 
@@ -39,7 +39,7 @@ module Puppet::Util::Windows::ADSI
             buffer_size.write_dword(max_length) # length in TCHARs
 
             if GetComputerNameW(buffer, buffer_size) == FFI::WIN32_FALSE
-              raise Puppet::Util::Windows::Error.new("Failed to get computer name")
+              raise Puppet::Util::Windows::Error.new(_("Failed to get computer name"))
             end
             @computer_name = buffer.read_wide_string(buffer_size.read_dword)
           end
@@ -57,7 +57,7 @@ module Puppet::Util::Windows::ADSI
     end
 
     # This method should *only* be used to generate WinNT://<SID> style monikers
-    # used for IAdsGroup::Add / IAdsGroup::Remove.  These URIs are not useable
+    # used for IAdsGroup::Add / IAdsGroup::Remove.  These URIs are not usable
     # to resolve an account with WIN32OLE.connect
     # Valid input is a SID::Principal, S-X-X style SID string or any valid
     # account name with or without domain prefix
@@ -66,7 +66,7 @@ module Puppet::Util::Windows::ADSI
       return sid_uri(sid) if sid.kind_of?(Puppet::Util::Windows::SID::Principal)
 
       begin
-        sid = Puppet::Util::Windows::SID.name_to_sid_object(sid)
+        sid = Puppet::Util::Windows::SID.name_to_principal(sid)
         sid_uri(sid)
       rescue Puppet::Util::Windows::Error, Puppet::Error
         nil
@@ -77,7 +77,7 @@ module Puppet::Util::Windows::ADSI
     # used for IAdsGroup::Add / IAdsGroup::Remove.  These URIs are not useable
     # to resolve an account with WIN32OLE.connect
     def sid_uri(sid)
-      raise Puppet::Error.new( "Must use a valid SID::Principal" ) if !sid.kind_of?(Puppet::Util::Windows::SID::Principal)
+      raise Puppet::Error.new( _("Must use a valid SID::Principal") ) if !sid.kind_of?(Puppet::Util::Windows::SID::Principal)
 
       "WinNT://#{sid.sid}"
     end
@@ -107,8 +107,19 @@ module Puppet::Util::Windows::ADSI
   end
 
   module Shared
+    def localized_domains
+      @localized_domains ||= [
+        # localized version of BUILTIN
+        # for instance VORDEFINIERT on German Windows
+        Puppet::Util::Windows::SID.sid_to_name('S-1-5-32').upcase,
+        # localized version of NT AUTHORITY (can't use S-1-5)
+        # for instance AUTORITE NT on French Windows
+        Puppet::Util::Windows::SID.name_to_principal('SYSTEM').domain.upcase
+      ]
+    end
+
     def uri(name, host = '.')
-      host = '.' if ['NT AUTHORITY', 'BUILTIN', Socket.gethostname].include?(host)
+      host = '.' if (localized_domains << Socket.gethostname.upcase).include?(host.upcase)
 
       # group or user
       account_type = self.name.split('::').last.downcase
@@ -118,7 +129,7 @@ module Puppet::Util::Windows::ADSI
 
     def parse_name(name)
       if name =~ /\//
-        raise Puppet::Error.new( "Value must be in DOMAIN\\user style syntax" )
+        raise Puppet::Error.new( _("Value must be in DOMAIN\\user style syntax") )
       end
 
       matches = name.scan(/((.*)\\)?(.*)/)
@@ -128,10 +139,12 @@ module Puppet::Util::Windows::ADSI
       return account, domain
     end
 
+    # returns Puppet::Util::Windows::SID::Principal[]
+    # may contain objects that represent unresolvable SIDs
     def get_sids(adsi_child_collection)
       sids = []
       adsi_child_collection.each do |m|
-        sids << Puppet::Util::Windows::SID.octet_string_to_sid_object(m.objectSID)
+        sids << Puppet::Util::Windows::SID.ads_to_principal(m)
       end
 
       sids
@@ -141,8 +154,8 @@ module Puppet::Util::Windows::ADSI
       return {} if names.nil? || names.empty?
 
       sids = names.map do |name|
-        sid = Puppet::Util::Windows::SID.name_to_sid_object(name)
-        raise Puppet::Error.new( "Could not resolve name: #{name}" ) if !sid
+        sid = Puppet::Util::Windows::SID.name_to_principal(name)
+        raise Puppet::Error.new( _("Could not resolve name: %{name}") % { name: name } ) if !sid
         [sid.sid, sid]
       end
 
@@ -172,7 +185,7 @@ module Puppet::Util::Windows::ADSI
     end
 
     def sid
-      @sid ||= Puppet::Util::Windows::SID.octet_string_to_sid_object(native_user.objectSID)
+      @sid ||= Puppet::Util::Windows::SID.octet_string_to_principal(native_user.objectSID)
     end
 
     def uri
@@ -184,6 +197,8 @@ module Puppet::Util::Windows::ADSI
     end
 
     def [](attribute)
+      # Setting WIN32OLE.codepage in the microsoft_windows feature ensures
+      # values are returned as UTF-8
       native_user.Get(attribute)
     end
 
@@ -198,12 +213,12 @@ module Puppet::Util::Windows::ADSI
         # ERROR_BAD_USERNAME 2202L from winerror.h
         if e.message =~ /8007089A/m
           raise Puppet::Error.new(
-           "Puppet is not able to create/delete domain users with the user resource.",
+           _("Puppet is not able to create/delete domain users with the user resource."),
            e
           )
         end
 
-        raise Puppet::Error.new( "User update failed: #{e}", e )
+        raise Puppet::Error.new( _("User update failed: %{e}") % { e: e }, e )
       end
       self
     end
@@ -234,6 +249,8 @@ module Puppet::Util::Windows::ADSI
       # https://msdn.microsoft.com/en-us/library/aa746342.aspx
       # WIN32OLE objects aren't enumerable, so no map
       groups = []
+      # Setting WIN32OLE.codepage in the microsoft_windows feature ensures
+      # values are returned as UTF-8
       native_user.Groups.each {|g| groups << g.Name} rescue nil
       groups
     end
@@ -296,7 +313,7 @@ module Puppet::Util::Windows::ADSI
 
     def self.create(name)
       # Windows error 1379: The specified local group already exists.
-      raise Puppet::Error.new( "Cannot create user if group '#{name}' exists." ) if Puppet::Util::Windows::ADSI::Group.exists? name
+      raise Puppet::Error.new(_("Cannot create user if group '%{name}' exists.") % { name: name }) if Puppet::Util::Windows::ADSI::Group.exists? name
       new(name, Puppet::Util::Windows::ADSI.create(name, 'user'))
     end
 
@@ -310,7 +327,7 @@ module Puppet::Util::Windows::ADSI
           buffer_size.write_dword(max_length) # length in TCHARs
 
           if GetUserNameW(buffer, buffer_size) == FFI::WIN32_FALSE
-            raise Puppet::Util::Windows::Error.new("Failed to get user name")
+            raise Puppet::Util::Windows::Error.new(_("Failed to get user name"))
           end
           # buffer_size includes trailing NULL
           user_name = buffer.read_wide_string(buffer_size.read_dword - 1)
@@ -320,9 +337,13 @@ module Puppet::Util::Windows::ADSI
       user_name
     end
 
+    def self.current_user_sid
+      Puppet::Util::Windows::SID.name_to_principal(current_user_name)
+    end
+
     def self.exists?(name_or_sid)
       well_known = false
-      if (sid = Puppet::Util::Windows::SID.name_to_sid_object(name_or_sid))
+      if (sid = Puppet::Util::Windows::SID.name_to_principal(name_or_sid))
         return true if sid.account_type == :SidTypeUser
 
         # 'well known group' is special as it can be a group like Everyone OR a user like SYSTEM
@@ -353,6 +374,8 @@ module Puppet::Util::Windows::ADSI
 
       users = []
       wql.each do |u|
+        # Setting WIN32OLE.codepage in the microsoft_windows feature ensures
+        # values are returned as UTF-8
         users << new(u.name)
       end
 
@@ -377,12 +400,12 @@ module Puppet::Util::Windows::ADSI
         Puppet::Util::Windows::ADSI.wmi_connection.Delete("Win32_UserProfile.SID='#{sid}'")
       rescue WIN32OLERuntimeError => e
         # https://social.technet.microsoft.com/Forums/en/ITCG/thread/0f190051-ac96-4bf1-a47f-6b864bfacee5
-        # Prior to Vista SP1, there's no builtin way to programmatically
+        # Prior to Vista SP1, there's no built-in way to programmatically
         # delete user profiles (except for delprof.exe). So try to delete
         # but warn if we fail
         raise e unless e.message.include?('80041010')
 
-        Puppet.warning "Cannot delete user profile for '#{sid}' prior to Vista SP1"
+        Puppet.warning _("Cannot delete user profile for '%{sid}' prior to Vista SP1") % { sid: sid }
       end
     end
   end
@@ -410,7 +433,7 @@ module Puppet::Util::Windows::ADSI
     end
 
     def sid
-      @sid ||= Puppet::Util::Windows::SID.octet_string_to_sid_object(native_group.objectSID)
+      @sid ||= Puppet::Util::Windows::SID.octet_string_to_principal(native_group.objectSID)
     end
 
     def commit
@@ -420,12 +443,12 @@ module Puppet::Util::Windows::ADSI
         # ERROR_BAD_USERNAME 2202L from winerror.h
         if e.message =~ /8007089A/m
           raise Puppet::Error.new(
-            "Puppet is not able to create/delete domain groups with the group resource.",
+            _("Puppet is not able to create/delete domain groups with the group resource."),
             e
           )
         end
 
-        raise Puppet::Error.new( "Group update failed: #{e}", e )
+        raise Puppet::Error.new( _("Group update failed: %{error}") % { error: e }, e )
       end
       self
     end
@@ -442,16 +465,13 @@ module Puppet::Util::Windows::ADSI
       end
     end
 
+    # returns Puppet::Util::Windows::SID::Principal[]
+    # may contain objects that represent unresolvable SIDs
+    # qualified account names are returned by calling #domain_account
     def members
-      # WIN32OLE objects aren't enumerable, so no map
-      members = []
-      native_group.Members.each {|m| members << m.Name}
-      members
-    end
-
-    def member_sids
       self.class.get_sids(native_group.Members)
     end
+    alias member_sids members
 
     def set_members(desired_members, inclusive = true)
       return if desired_members.nil?
@@ -479,13 +499,13 @@ module Puppet::Util::Windows::ADSI
 
     def self.create(name)
       # Windows error 2224: The account already exists.
-      raise Puppet::Error.new( "Cannot create group if user '#{name}' exists." ) if Puppet::Util::Windows::ADSI::User.exists? name
+      raise Puppet::Error.new( _("Cannot create group if user '%{name}' exists.") % { name: name } ) if Puppet::Util::Windows::ADSI::User.exists? name
       new(name, Puppet::Util::Windows::ADSI.create(name, 'group'))
     end
 
     def self.exists?(name_or_sid)
       well_known = false
-      if (sid = Puppet::Util::Windows::SID.name_to_sid_object(name_or_sid))
+      if (sid = Puppet::Util::Windows::SID.name_to_principal(name_or_sid))
         return true if sid.account_type == :SidTypeGroup
 
         # 'well known group' is special as it can be a group like Everyone OR a user like SYSTEM
@@ -510,10 +530,12 @@ module Puppet::Util::Windows::ADSI
     end
 
     def self.each(&block)
-      wql = Puppet::Util::Windows::ADSI.execquery( 'select name from win32_group where localaccount = "TRUE"' )
+      wql = Puppet::Util::Windows::ADSI.execquery('select name from win32_group where localaccount = "TRUE"')
 
       groups = []
       wql.each do |g|
+        # Setting WIN32OLE.codepage in the microsoft_windows feature ensures
+        # values are returned as UTF-8
         groups << new(g.name)
       end
 
